==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/CompanyM365contactEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.CompanyM365contactCountEndpoint import CompanyM365contactCountEndpoint
from pyconnectwise.endpoints.manage.CompanyM365contactIdEndpoint import CompanyM365contactIdEndpoint
from pyconnectwise.models.manage import M365Contact
from pyconnectwise.responses.paginated_response import PaginatedResponse


class CompanyM365contactEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "m365contact", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(CompanyM365contactCountEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> CompanyM365contactIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized CompanyM365contactIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            CompanyM365contactIdEndpoint: The initialized CompanyM365contactIdEndpoint object.
        """
        child = CompanyM365contactIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[M365Contact]:
        """
        Performs a GET request against the /company/m365contact endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[M365Contact]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            M365Contact,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[M365Contact]:
        """
        Performs a GET request against the /company/m365contact endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[M365Contact]: The parsed response data.
        """
        return self._parse_many(M365Contact, super()._make_request("GET", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/CompanyM365contactEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.CompanyM365contactCountEndpoint import CompanyM365contactCountEndpoint
from pyconnectwise.endpoints.manage.CompanyM365contactIdEndpoint import CompanyM365contactIdEndpoint
from pyconnectwise.models.manage import M365Contact
from pyconnectwise.responses.paginated_response import PaginatedResponse


class CompanyM365contactEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "m365contact", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(CompanyM365contactCountEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> CompanyM365contactIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized CompanyM365contactIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            CompanyM365contactIdEndpoint: The initialized CompanyM365contactIdEndpoint object.
        """
        child = CompanyM365contactIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[M365Contact]:
        """
        Performs a GET request against the /company/m365contact endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[M365Contact]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params), M365Contact, self, page, page_size, params
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[M365Contact]:
        """
        Performs a GET request against the /company/m365contact endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[M365Contact]: The parsed response data.
        """
        return self._parse_many(M365Contact, super()._make_request("GET", data=data, params=params).json())
